<?php
require_once 'config.php';

$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$per_page = HOMEPAGE_POSTS_PER_PAGE;
$offset = ($current_page - 1) * $per_page;

// Fetch posts from Supabase
$url = SUPABASE_URL . "articles?select=*&order=date.desc&limit=$per_page&offset=$offset";
$headers = [
    'apikey: ' . SUPABASE_KEY,
    'Authorization: Bearer ' . SUPABASE_KEY,
];

$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
$response = curl_exec($ch);
curl_close($ch);

$posts = json_decode($response, true);
$total_posts = count($posts);

include 'header.php';
?>

<main class="homepage">
    <h1>Recent Posts</h1>
    
    <div class="posts-grid">
        <?php foreach ($posts as $post): ?>
            <article class="post-card">
                <?php if ($post['image_path']): ?>
                    <img src="<?= htmlspecialchars($post['image_path']) ?>" 
                         alt="<?= htmlspecialchars($post['post_title']) ?>"
                         class="post-thumbnail">
                <?php endif; ?>
                <h2><?= htmlspecialchars($post['post_title']) ?></h2>
                <div class="post-excerpt">
                    <?= substr(strip_tags($post['post_content']), 0, 250) ?>...
                </div>
                <a href="/<?= htmlspecialchars($post['post_path']) ?>" class="read-more">
                    Read More
                </a>
            </article>
        <?php endforeach; ?>
    </div>

    <!-- Pagination -->
    <div class="pagination">
        <?php if ($current_page > 1): ?>
            <a href="/?page=<?= $current_page - 1 ?>">Previous</a>
        <?php endif; ?>
        
        <?php if ($total_posts == $per_page): ?>
            <a href="/?page=<?= $current_page + 1 ?>">Next</a>
        <?php endif; ?>
    </div>
</main>

<?php include 'footer.php'; ?>