<?php
require_once 'config.php';

// Get requested post path
$post_path = trim(parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH), '/');

// Fetch main post
$url = SUPABASE_URL . "articles?post_path=eq." . urlencode($post_path);
$headers = [
    'apikey: ' . SUPABASE_KEY,
    'Authorization: Bearer ' . SUPABASE_KEY,
];

$ch = curl_init();
curl_setopt($ch, CURLOPT_URL, $url);
curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
$response = curl_exec($ch);
curl_close($ch);

$posts = json_decode($response, true);
$post = $posts[0] ?? null;

// Handle 404 if post not found
if (!$post) {
    header('HTTP/1.0 404 Not Found');
    include '404.php';
    exit;
}

// Set page title for header
$page_title = htmlspecialchars($post['post_title']) . ' - ' . SITE_NAME;

// Fetch recent posts for sidebar (excluding current post)
$current_post_id = $post['post_id'];
$sidebar_limit = SIDEBAR_POSTS_COUNT;
$sidebar_url = SUPABASE_URL . "articles?select=post_id,post_title,post_path"
    . "&post_id=neq.$current_post_id"
    . "&order=date.desc"
    . "&limit=$sidebar_limit";

$sidebar_ch = curl_init();
curl_setopt($sidebar_ch, CURLOPT_URL, $sidebar_url);
curl_setopt($sidebar_ch, CURLOPT_RETURNTRANSFER, true);
curl_setopt($sidebar_ch, CURLOPT_HTTPHEADER, $headers);
$sidebar_response = curl_exec($sidebar_ch);
curl_close($sidebar_ch);

$sidebar_posts = json_decode($sidebar_response, true) ?? [];

include 'header.php';
?>

<main class="post-page">
    <article class="main-content">
        <h1><?= htmlspecialchars($post['post_title']) ?></h1>
        
        <?php if (!empty($post['image_path'])): ?>
            <img src="<?= htmlspecialchars($post['image_path']) ?>" 
                 alt="<?= htmlspecialchars($post['post_title']) ?>"
                 class="post-image">
        <?php endif; ?>
        
        <div class="post-content">
            <?= $post['post_content'] ?>
        </div>
    </article>

    <aside class="sidebar">
        <h3>Recent Posts</h3>
        <?php if (!empty($sidebar_posts)): ?>
            <?php foreach ($sidebar_posts as $sidebar_post): ?>
                <div class="sidebar-post">
                    <a href="/<?= htmlspecialchars($sidebar_post['post_path']) ?>">
                        <?= htmlspecialchars($sidebar_post['post_title']) ?>
                    </a>
                </div>
            <?php endforeach; ?>
        <?php else: ?>
            <p>No recent posts found</p>
        <?php endif; ?>
    </aside>
</main>

<?php include 'footer.php'; ?>